@@ -91,6 +91,13 @@ class UIBase:
         ds = s.folderlist(destlist)
         s._msg("Deleting message %d in %s" % (uid, ds))
 
+    def deletingmessages(s, uidlist, destlist):
+        ds = s.folderlist(destlist)
+        s._msg("Deleting %d messages (%s) in %s" % \
+               (len(uidlist),
+                ", ".join([str(u) for u in uidlist]),
+                ds))
+
     def addingflags(s, uid, flags, destlist):
         ds = s.folderlist(destlist)
         s._msg("Adding flags %s to message %d on %s" % \
@@ -103,6 +110,21 @@ class UIBase:
 
     ################################################## Other
 
+    def sleep(s, sleepsecs):
+        """This function does not actually output anything, but handles
+        the overall sleep, dealing with updates as necessary.  It will,
+        however, call sleeping() which DOES output something.
+
+        Returns 0 if timeout expired, 1 if there is a request to cancel
+        the timer, and 2 if there is a request to abort the program."""
+
+        abortsleep = 0
+        while sleepsecs > 0 and not abortsleep:
+            abortsleep = s.sleeping(1, sleepsecs)
+            sleepsecs -= 1
+        s.sleeping(0, 0)               # Done sleeping.
+        return abortsleep
+
     def sleeping(s, sleepsecs, remainingsecs):
         """Sleep for sleepsecs, remainingsecs to go.
         If sleepsecs is 0, indicates we're done sleeping.
